pub struct SubscriptionFilter(FilterExpression);Expand description
A validated server-side publication tag filter.
Tuple Fields
0: FilterExpressionImplementations
Sourceimpl SubscriptionFilter
impl SubscriptionFilter
Sourcepub fn equal(
key: impl Into<String>,
value: FilterValue,
) -> Result<Self, FilterError>
pub fn equal( key: impl Into<String>, value: FilterValue, ) -> Result<Self, FilterError>
Matches tags whose value equals value.
Errors
Returns an error if the key or required value is empty.
Sourcepub fn not_equal(
key: impl Into<String>,
value: FilterValue,
) -> Result<Self, FilterError>
pub fn not_equal( key: impl Into<String>, value: FilterValue, ) -> Result<Self, FilterError>
Matches tags whose value does not equal value.
Errors
Returns an error if the key or required value is empty.
Sourcepub fn is_in<I>(key: impl Into<String>, values: I) -> Result<Self, FilterError>where
I: IntoIterator<Item = FilterValue>,
pub fn is_in<I>(key: impl Into<String>, values: I) -> Result<Self, FilterError>where
I: IntoIterator<Item = FilterValue>,
Matches tags whose value is present in values.
Errors
Returns an error if the key or value list is empty.
Sourcepub fn is_not_in<I>(
key: impl Into<String>,
values: I,
) -> Result<Self, FilterError>where
I: IntoIterator<Item = FilterValue>,
pub fn is_not_in<I>(
key: impl Into<String>,
values: I,
) -> Result<Self, FilterError>where
I: IntoIterator<Item = FilterValue>,
Matches tags whose value is absent from values.
Errors
Returns an error if the key or value list is empty.
Sourcepub fn not_exists(key: impl Into<String>) -> Result<Self, FilterError>
pub fn not_exists(key: impl Into<String>) -> Result<Self, FilterError>
Sourcepub fn starts_with(
key: impl Into<String>,
value: FilterValue,
) -> Result<Self, FilterError>
pub fn starts_with( key: impl Into<String>, value: FilterValue, ) -> Result<Self, FilterError>
Matches text tags beginning with value.
Errors
Returns an error if the key is empty or the value is not non-empty text.
Sourcepub fn ends_with(
key: impl Into<String>,
value: FilterValue,
) -> Result<Self, FilterError>
pub fn ends_with( key: impl Into<String>, value: FilterValue, ) -> Result<Self, FilterError>
Matches text tags ending with value.
Errors
Returns an error if the key is empty or the value is not non-empty text.
Sourcepub fn contains(
key: impl Into<String>,
value: FilterValue,
) -> Result<Self, FilterError>
pub fn contains( key: impl Into<String>, value: FilterValue, ) -> Result<Self, FilterError>
Matches text tags containing value.
Errors
Returns an error if the key is empty or the value is not non-empty text.
Sourcepub fn greater_than(
key: impl Into<String>,
value: FilterValue,
) -> Result<Self, FilterError>
pub fn greater_than( key: impl Into<String>, value: FilterValue, ) -> Result<Self, FilterError>
Matches numeric tags greater than value.
Errors
Returns an error if the key is empty or the value is not numeric.
Sourcepub fn greater_than_or_equal(
key: impl Into<String>,
value: FilterValue,
) -> Result<Self, FilterError>
pub fn greater_than_or_equal( key: impl Into<String>, value: FilterValue, ) -> Result<Self, FilterError>
Matches numeric tags greater than or equal to value.
Errors
Returns an error if the key is empty or the value is not numeric.
Sourcepub fn less_than(
key: impl Into<String>,
value: FilterValue,
) -> Result<Self, FilterError>
pub fn less_than( key: impl Into<String>, value: FilterValue, ) -> Result<Self, FilterError>
Matches numeric tags less than value.
Errors
Returns an error if the key is empty or the value is not numeric.
Sourcepub fn less_than_or_equal(
key: impl Into<String>,
value: FilterValue,
) -> Result<Self, FilterError>
pub fn less_than_or_equal( key: impl Into<String>, value: FilterValue, ) -> Result<Self, FilterError>
Matches numeric tags less than or equal to value.
Errors
Returns an error if the key is empty or the value is not numeric.
Sourcepub fn and<I>(filters: I) -> Result<Self, FilterError>where
I: IntoIterator<Item = Self>,
pub fn and<I>(filters: I) -> Result<Self, FilterError>where
I: IntoIterator<Item = Self>,
Requires every child expression to match.
Errors
Returns an error if no child expressions are provided.
Sourcepub fn or<I>(filters: I) -> Result<Self, FilterError>where
I: IntoIterator<Item = Self>,
pub fn or<I>(filters: I) -> Result<Self, FilterError>where
I: IntoIterator<Item = Self>,
Requires at least one child expression to match.
Errors
Returns an error if no child expressions are provided.
fn comparison( key: impl Into<String>, comparison: Comparison, ) -> Result<Self, FilterError>
fn value_comparison( key: impl Into<String>, value: FilterValue, comparison: &'static str, required_kind: Option<&'static str>, constructor: impl FnOnce(FilterValue) -> Comparison, ) -> Result<Self, FilterError>
fn list_comparison<I>(
key: impl Into<String>,
values: I,
comparison: &'static str,
constructor: impl FnOnce(Vec<FilterValue>) -> Comparison,
) -> Result<Self, FilterError>where
I: IntoIterator<Item = FilterValue>,
fn group<I>(
filters: I,
operator: &'static str,
constructor: impl FnOnce(Vec<Self>) -> FilterExpression,
) -> Result<Self, FilterError>where
I: IntoIterator<Item = Self>,
fn precedence(&self) -> u8
fn fmt_with_precedence( &self, formatter: &mut Formatter<'_>, parent_precedence: u8, ) -> Result